@@ -37,6 +37,8 @@ for finder_string, finder_function in ELEMENT_FINDERS.iteritems():
         @step(r'should( not)? see that the( first)?( last)? %s %s contains? "(.*)"' % (ELEMENT_THING_STRING, finder_string))
         def _this_step(step, negate, first, last, find_pattern, content):
             ele = _get_element(finder_function, first, last, find_pattern)
+            print ele.text
+            print "foo"
             assert_with_negate(content in ele.text, negate)
 
         return _this_step
